package com.landray.kmss.sys.attachment.dao.hibernate;

import java.util.Iterator;
import java.util.Map;
import com.landray.kmss.sys.config.design.SysConfigs;
import org.hibernate.query.Query;
import java.util.Collection;
import java.util.ArrayList;
import com.landray.kmss.util.ModelUtil;
import com.landray.kmss.common.dao.HQLInfo;
import java.util.Date;
import java.io.Serializable;
import com.landray.kmss.sys.attachment.model.SysAttRtfData;
import java.util.List;
import com.landray.kmss.sys.attachment.model.SysAttBase;
import com.landray.kmss.common.model.IBaseModel;
import com.landray.kmss.sys.attachment.dao.ISysAttMainCoreInnerDao;
import com.landray.kmss.common.dao.BaseCoreInnerDaoImp;

public class SysAttMainCoreInnerDaoImp extends BaseCoreInnerDaoImp implements ISysAttMainCoreInnerDao
{
    public String add(final IBaseModel modelObj) throws Exception {
        final SysAttBase sysAttMain = (SysAttBase)modelObj;
        this.getHibernateTemplate().save((Object)modelObj);
        this.flushHibernateSession();
        return sysAttMain.getFdId();
    }
    
    public void update(final IBaseModel modelObj) throws Exception {
        this.getHibernateTemplate().saveOrUpdate((Object)modelObj);
        this.flushHibernateSession();
    }
    
    public void delete(final IBaseModel modelObj) throws Exception {
        this.getHibernateTemplate().delete((Object)modelObj);
        this.flushHibernateSession();
    }
    
    public List findByModelKey(final String modelName, final String modelId, final String key) throws Exception {
        final String hql = "from SysAttMain where fdModelName=? and fdModelId=? and fdKey=? order by fdOrder asc, fdId asc";
        return this.getHibernateTemplate().find(hql, new Object[] { modelName, modelId, key });
    }
    
    public List findAttListByModel(final String modelName, final String modelId) throws Exception {
        final String hql = "from SysAttMain where fdModelName=? and fdModelId=? order by fdOrder asc, fdId asc";
        return this.getHibernateTemplate().find(hql, new Object[] { modelName, modelId });
    }
    
    public List findModelKeys(final String modelName, final String modelId) throws Exception {
        final String hql = "select distinct fdKey from SysAttMain where fdModelName=? and fdModelId=? ";
        return this.getHibernateTemplate().find(hql, new Object[] { modelName, modelId });
    }
    
    public SysAttRtfData findRtfDataByPrimaryKey(final String fdId) throws Exception {
        return (SysAttRtfData)this.getHibernateTemplate().load((Class)SysAttRtfData.class, (Serializable)fdId);
    }
    
    public List findAttData(final Date begin, final Date end) throws Exception {
        return this.getAttDataByTime(begin, end);
    }
    
    public List findModelsByIds(final String[] fdId) throws Exception {
        return this.findModels(fdId);
    }
    
    public int clearAttachment(final IBaseModel model, final String fdKey) throws Exception {
        final String modelId = model.getFdId();
        final String modelName = model.getClass().getName();
        final String hql = "delete from SysAttMain where fdKey=? and fdModelId=? and fdModelName=?";
        return this.getHibernateTemplate().bulkUpdate(hql, new Object[] { fdKey, modelId, modelName });
    }
    
    public List getCorePropsModels(final IBaseModel mainModel, final String key) throws Exception {
        final HQLInfo hqlInfo = new HQLInfo();
        final String tableName = ModelUtil.getModelTableName((Object)this.getModelName());
        String whereBlock = String.valueOf(tableName) + ".fdModelName=:fdModelName and " + tableName + ".fdModelId=:fdModelId";
        hqlInfo.setParameter("fdModelName", (Object)ModelUtil.getModelClassName((Object)mainModel));
        hqlInfo.setParameter("fdModelId", (Object)mainModel.getFdId());
        if (key != null) {
            whereBlock = String.valueOf(whereBlock) + " and " + tableName + ".fdKey=:fdKey";
            hqlInfo.setParameter("fdKey", (Object)key);
        }
        hqlInfo.setWhereBlock(whereBlock);
        hqlInfo.setSelectBlock("fdId,fdFileName,fdContentType");
        return this.findValue(hqlInfo);
    }
    
    protected List findModels(final String[] fdId) {
        final List<String> idList = new ArrayList<String>();
        for (int i = 0; i < fdId.length; ++i) {
            idList.add(fdId[i]);
        }
        final String hql = "from SysAttMain where fdId in(:idList)";
        final Query query = this.getHibernateSession().createQuery(hql);
        query.setParameterList("idList", (Collection)idList);
        return query.list();
    }
    
    protected List getAttDataByTime(final Date begin, final Date end) throws Exception {
        if (begin == null) {
            return this.getAttData(end);
        }
        return this.getAttData(begin, end);
    }
    
    protected List getAttData(final Date end) throws Exception {
        String hql = "from SysAttMain where fdModelId is not null and docCreateTime < :end";
        hql = String.valueOf(hql) + this.getModelCondition();
        final Query query = this.getHibernateSession().createQuery(hql);
        query.setTimestamp("end", end);
        return query.list();
    }
    
    protected List getAttData(final Date begin, final Date end) throws Exception {
        String hql = "from SysAttMain where fdModelId is not null and docCreateTime between :begin and :end";
        hql = String.valueOf(hql) + this.getModelCondition();
        final Query query = this.getHibernateSession().createQuery(hql);
        query.setTimestamp("begin", begin);
        query.setTimestamp("end", end);
        return query.list();
    }
    
    private String getModelCondition() {
        String str = "";
        int n = 0;
        final Map ftSearchs = SysConfigs.getInstance().getFtSearchs();
        final Iterator iter = ftSearchs.keySet().iterator();
        while (iter.hasNext()) {
            if (n > 0) {
                str = String.valueOf(str) + ",";
            }
            str = String.valueOf(str) + "'" + iter.next() + "'";
            ++n;
        }
        return " and fdModelName in(" + ((str.length() > 0) ? str : "''") + ")";
    }
}
